import { Currency } from "./Currency";
import { PhoneNumber } from "./PhoneNumber";
describe("Currency function", () => {
    it("should format a string into a currency with default options", () => {
        const result = Currency("1000");
        expect(result).toBe("$1,000.00");
    });
    it("should format a string into a currency with custom digit options", () => {
        const result = Currency("1000", 4);
        expect(result).toBe("$1,000.0000");
    });
    it("should format a string into a currency with custom currency type", () => {
        const result = Currency("1000", 2, "CAD");
        expect(result).toBe("CA$1,000.00");
    });
    it("should format a number into a currency with default options", () => {
        const result = Currency(1000);
        expect(result).toBe("$1,000.00");
    });
    it("should format a number into a currency with custom digit options", () => {
        const result = Currency(1000, 4);
        expect(result).toBe("$1,000.0000");
    });
    it("should format a number into a currency with custom currency type", () => {
        const result = Currency(1000, 2, "CAD");
        expect(result).toBe("CA$1,000.00");
    });
});
describe("PhoneNumber", () => {
    it("should format a string with numbers into a phone number string", () => {
        expect(PhoneNumber("1234567890")).toBe("(123) 456-7890");
    });
    it("should format a number into a phone number string", () => {
        expect(PhoneNumber(1234567890)).toBe("(123) 456-7890");
    });
    it("should handle an empty string and return an empty string", () => {
        expect(PhoneNumber("")).toBe("");
    });
    it("should handle a string with non-numeric characters and return an empty string", () => {
        expect(PhoneNumber("abc123")).toBe("");
    });
    it("should handle a number with non-numeric characters and return an empty string", () => {
        expect(PhoneNumber("abc")).toBe("");
    });
});
