/**
 * Checks if the given input is a valid number and optionally, if it falls within a specific range.
 *
 * @param {string | number} input - The value to check.
 * @param {number} [minInput] - The minimum acceptable value for the input.
 * @param {number} [maxInput] - The maximum acceptable value for the input.
 * @returns {boolean} - Returns `true` if the input is a valid number and falls within the specified range. Otherwise, it returns `false`.
 */
export function ValidNumber(input, minInput = Number.MIN_SAFE_INTEGER, maxInput = Number.MAX_SAFE_INTEGER) {
    let num;
    if (typeof input === "string") {
        if (input === "")
            return false;
        num = Number(input);
        if (isNaN(num))
            return false;
    }
    else {
        num = input;
    }
    return !(num < minInput || num > maxInput);
}
